@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "857a225a157994ba7899d29493ef7f60aff453f7",
-  "branchName": "release-client-6.x",
-  "buildTime": "2024-06-14 06:47:38 GMT",
-  "buildVersion": "1.0.422",
+  "commitId": "b965116af11fde2db28245622ec9b97ffc2cb90a",
+  "branchName": "release-client-6.1.x",
+  "buildTime": "2024-06-27 05:56:26 GMT",
+  "buildVersion": "1.0.503",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.f0f0dc24.css",
-    "@zoom/client-scheduler/static/css/index.ef4f5c13.css"
+    "@zoom/client-scheduler/static/css/index.1f8c4026.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.0a656d4cd47956d29c87.js",
-    "@zoom/client-scheduler/index.0a656d4cd47956d29c87.js"
+    "@zoom/client-scheduler/chunk-vendors.4061f47f68bdcc205e6c.js",
+    "@zoom/client-scheduler/index.4061f47f68bdcc205e6c.js"
   ],
   "key": "clientSchedulerResource"
 };
